# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ubii/proto_v2/types/sessions/session.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ubii.proto_v2.types.sessions import ioMappings_pb2 as ubii_dot_proto__v2_dot_types_dot_sessions_dot_ioMappings__pb2
from ubii.proto_v2.types.processing import processingModule_pb2 as ubii_dot_proto__v2_dot_types_dot_processing_dot_processingModule__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ubii/proto_v2/types/sessions/session.proto',
  package='ubii.proto_v2.types.sessions',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n*ubii/proto_v2/types/sessions/session.proto\x12\x1cubii.proto_v2.types.sessions\x1a-ubii/proto_v2/types/sessions/ioMappings.proto\x1a\x35ubii/proto_v2/types/processing/processingModule.proto\"\xb2\x02\n\x07Session\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12L\n\x12processing_modules\x18\x03 \x03(\x0b\x32\x30.ubii.proto_v2.types.processing.ProcessingModule\x12<\n\x0bio_mappings\x18\x04 \x03(\x0b\x32\'.ubii.proto_v2.types.sessions.IOMapping\x12\x0c\n\x04tags\x18\x05 \x03(\t\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\x12\x0f\n\x07\x61uthors\x18\x07 \x03(\t\x12;\n\x06status\x18\x08 \x01(\x0e\x32+.ubii.proto_v2.types.sessions.SessionStatus\x12\x10\n\x08\x65\x64itable\x18\t \x01(\x08\"F\n\x0bSessionList\x12\x37\n\x08\x65lements\x18\x01 \x03(\x0b\x32%.ubii.proto_v2.types.sessions.Session*B\n\rSessionStatus\x12\x0b\n\x07\x43REATED\x10\x00\x12\x0b\n\x07RUNNING\x10\x01\x12\n\n\x06PAUSED\x10\x02\x12\x0b\n\x07STOPPED\x10\x03\x62\x06proto3'
  ,
  dependencies=[ubii_dot_proto__v2_dot_types_dot_sessions_dot_ioMappings__pb2.DESCRIPTOR,ubii_dot_proto__v2_dot_types_dot_processing_dot_processingModule__pb2.DESCRIPTOR,])

_SESSIONSTATUS = _descriptor.EnumDescriptor(
  name='SessionStatus',
  full_name='ubii.proto_v2.types.sessions.SessionStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CREATED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RUNNING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PAUSED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOPPED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=559,
  serialized_end=625,
)
_sym_db.RegisterEnumDescriptor(_SESSIONSTATUS)

SessionStatus = enum_type_wrapper.EnumTypeWrapper(_SESSIONSTATUS)
CREATED = 0
RUNNING = 1
PAUSED = 2
STOPPED = 3



_SESSION = _descriptor.Descriptor(
  name='Session',
  full_name='ubii.proto_v2.types.sessions.Session',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='ubii.proto_v2.types.sessions.Session.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='ubii.proto_v2.types.sessions.Session.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='processing_modules', full_name='ubii.proto_v2.types.sessions.Session.processing_modules', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='io_mappings', full_name='ubii.proto_v2.types.sessions.Session.io_mappings', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tags', full_name='ubii.proto_v2.types.sessions.Session.tags', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='ubii.proto_v2.types.sessions.Session.description', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='authors', full_name='ubii.proto_v2.types.sessions.Session.authors', index=6,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='ubii.proto_v2.types.sessions.Session.status', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='editable', full_name='ubii.proto_v2.types.sessions.Session.editable', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=179,
  serialized_end=485,
)


_SESSIONLIST = _descriptor.Descriptor(
  name='SessionList',
  full_name='ubii.proto_v2.types.sessions.SessionList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='elements', full_name='ubii.proto_v2.types.sessions.SessionList.elements', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=487,
  serialized_end=557,
)

_SESSION.fields_by_name['processing_modules'].message_type = ubii_dot_proto__v2_dot_types_dot_processing_dot_processingModule__pb2._PROCESSINGMODULE
_SESSION.fields_by_name['io_mappings'].message_type = ubii_dot_proto__v2_dot_types_dot_sessions_dot_ioMappings__pb2._IOMAPPING
_SESSION.fields_by_name['status'].enum_type = _SESSIONSTATUS
_SESSIONLIST.fields_by_name['elements'].message_type = _SESSION
DESCRIPTOR.message_types_by_name['Session'] = _SESSION
DESCRIPTOR.message_types_by_name['SessionList'] = _SESSIONLIST
DESCRIPTOR.enum_types_by_name['SessionStatus'] = _SESSIONSTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Session = _reflection.GeneratedProtocolMessageType('Session', (_message.Message,), {
  'DESCRIPTOR' : _SESSION,
  '__module__' : 'ubii.proto_v2.types.sessions.session_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.sessions.Session)
  })
_sym_db.RegisterMessage(Session)

SessionList = _reflection.GeneratedProtocolMessageType('SessionList', (_message.Message,), {
  'DESCRIPTOR' : _SESSIONLIST,
  '__module__' : 'ubii.proto_v2.types.sessions.session_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.sessions.SessionList)
  })
_sym_db.RegisterMessage(SessionList)


# @@protoc_insertion_point(module_scope)
